mws — boto v2.16.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.16.0 »

# mws

## boto.mws

## boto.mws.connection

class `boto.mws.connection.` `MWSConnection`(*args, **kw)
  `ResponseError`

    alias of `ResponseErrorFactory`

  `cancel_feed_submissions`(*args, **kw)

    MWS CancelFeedSubmissions/2009-01-01 API call; quota=10 restore=45.00 Cancels one or more feed submissions and returns a

    > count of the feed submissions that were canceled.

    Lists: FeedSubmissionIdList.Id, FeedTypeList.Type

  `cancel_fulfillment_order`(*args, **kw)

    MWS CancelFulfillmentOrder/2010-10-01 API call; quota=30 restore=0.50 Requests that Amazon stop attempting to fulfill an existing

    > fulfillment order.

    Required: SellerFulfillmentOrderId

  `cancel_report_requests`(*args, **kw)

    MWS CancelReportRequests/2009-01-01 API call; quota=10 restore=45.00 Cancel one or more report requests, returning the count of the canceled report requests and the report request information.

  `create_fulfillment_order`(*args, **kw)

    MWS CreateFulfillmentOrder/2010-10-01 API call; quota=30 restore=0.50 Requests that Amazon ship items from the seller’s inventory

    > to a destination address.

    Required: SellerFulfillmentOrderId+DisplayableOrderId+ShippingSpeedCategory+DisplayableOrderDateTime+DestinationAddress+DisplayableOrderComment+Items Objects: DestinationAddress, Items

  `create_inbound_shipment`(*args, **kw)

    MWS CreateInboundShipment/2010-10-01 API call; quota=30 restore=0.50 Creates an inbound shipment.

    Objects: InboundShipmentHeader, InboundShipmentItems Required: ShipmentId+InboundShipmentHeader+InboundShipmentItems

  `create_inbound_shipment_plan`(*args, **kw)

    MWS CreateInboundShipmentPlan/2010-10-01 API call; quota=30 restore=0.50 Returns the information required to create an inbound shipment.

    Objects: ShipFromAddress, InboundShipmentPlanRequestItems Required: ShipFromAddress+InboundShipmentPlanRequestItems

  `get_competitive_pricing_for_asin`(*args, **kw)

    MWS GetCompetitivePricingForASIN/2011-10-01 API call; quota=20 restore=10.00 Returns the current competitive pricing of a product,

    > based on the ASINs and MarketplaceId that you specify.

    Lists: ASINList.ASIN Required: MarketplaceId+ASINList

  `get_competitive_pricing_for_sku`(*args, **kw)

    MWS GetCompetitivePricingForSKU/2011-10-01 API call; quota=20 restore=10.00 Returns the current competitive pricing of a product,

    > based on the SellerSKUs and MarketplaceId that you specify.

    Lists: SellerSKUList.SellerSKU Required: MarketplaceId+SellerSKUList

  `get_feed_submission_count`(*args, **kw)

    MWS GetFeedSubmissionCount/2009-01-01 API call; quota=10 restore=45.00 Returns a count of the feeds submitted in the previous 90 days.

    Lists: FeedTypeList.Type, FeedProcessingStatusList.Status

  `get_feed_submission_list`(*args, **kw)

    MWS GetFeedSubmissionList/2009-01-01 API call; quota=10 restore=45.00 Returns a list of all feed submissions submitted in the

    > previous 90 days.

    Lists: FeedSubmissionIdList.Id, FeedTypeList.Type, FeedProcessingStatusList.Status

  `get_feed_submission_list_by_next_token`(*args, **kw)

    MWS GetFeedSubmissionListByNextToken/2009-01-01 API call; quota=0 restore=0.00 Returns a list of feed submissions using the NextToken parameter.

    Required: NextToken

  `get_feed_submission_result`(*args, **kw)

    MWS GetFeedSubmissionResult/2009-01-01 API call; quota=15 restore=60.00 Returns the feed processing report.

    Required: FeedSubmissionId

  `get_fulfillment_order`(*args, **kw)

    MWS GetFulfillmentOrder/2010-10-01 API call; quota=30 restore=0.50 Returns a fulfillment order based on a specified

    > SellerFulfillmentOrderId.

    Required: SellerFulfillmentOrderId

  `get_fulfillment_preview`(*args, **kw)

    MWS GetFulfillmentPreview/2010-10-01 API call; quota=30 restore=0.50 Returns a list of fulfillment order previews based on items

    > and shipping speed categories that you specify.

    Required: Address+Items Objects: Address, Items

  `get_inbound_service_status`(*args, **kw)

    MWS GetServiceStatus/2010-10-01 API call; quota=2 restore=300.00 Returns the operational status of the Fulfillment Inbound Shipment API section.

  `get_inventory_service_status`(*args, **kw)

    MWS GetServiceStatus/2010-10-01 API call; quota=2 restore=300.00 Returns the operational status of the Fulfillment Inventory API section.

  `get_lowest_offer_listings_for_asin`(*args, **kw)

    MWS GetLowestOfferListingsForASIN/2011-10-01 API call; quota=20 restore=5.00 Returns the lowest price offer listings for a specific

    > product by item condition and ASINs.

    Lists: ASINList.ASIN Required: MarketplaceId+ASINList

  `get_lowest_offer_listings_for_sku`(*args, **kw)

    MWS GetLowestOfferListingsForSKU/2011-10-01 API call; quota=20 restore=5.00 Returns the lowest price offer listings for a specific

    > product by item condition and SellerSKUs.

    Lists: SellerSKUList.SellerSKU Required: MarketplaceId+SellerSKUList

  `get_matching_product`(*args, **kw)

    MWS GetMatchingProduct/2011-10-01 API call; quota=20 restore=20.00 Returns a list of products and their attributes, based on

    > a list of ASIN values that you specify.

    Lists: ASINList.ASIN Required: MarketplaceId+ASINList

  `get_matching_product_for_id`(*args, **kw)

    MWS GetMatchingProductForId/2011-10-01 API call; quota=20 restore=20.00 Returns a list of products and their attributes, based on

    > a list of Product IDs that you specify.

    Lists: IdList.Id Required: MarketplaceId+IdType+IdList

  `get_order`(*args, **kw)

    MWS GetOrder/2011-01-01 API call; quota=6 restore=60.00 Returns an order for each AmazonOrderId that you specify.

    Lists: AmazonOrderId.Id Required: AmazonOrderId

  `get_orders_service_status`(*args, **kw)

    MWS GetServiceStatus/2011-01-01 API call; quota=2 restore=300.00 Returns the operational status of the Orders API section.

  `get_outbound_service_status`(*args, **kw)

    MWS GetServiceStatus/2010-10-01 API call; quota=2 restore=300.00 Returns the operational status of the Fulfillment Outbound API section.

  `get_package_tracking_details`(*args, **kw)

    MWS GetPackageTrackingDetails/2010-10-01 API call; quota=30 restore=0.50 Returns delivery tracking information for a package in

    > an outbound shipment for a Multi-Channel Fulfillment order.

    Required: PackageNumber

  `get_product_categories_for_asin`(*args, **kw)

    MWS GetProductCategoriesForASIN/2011-10-01 API call; quota=20 restore=20.00 Returns the product categories that an ASIN belongs to.

    Required: MarketplaceId+ASIN

  `get_product_categories_for_sku`(*args, **kw)

    MWS GetProductCategoriesForSKU/2011-10-01 API call; quota=20 restore=20.00 Returns the product categories that a SellerSKU belongs to.

    Required: MarketplaceId+SellerSKU

  `get_products_service_status`(*args, **kw)

    MWS GetServiceStatus/2011-10-01 API call; quota=2 restore=300.00 Returns the operational status of the Products API section.

  `get_report`(*args, **kw)

    MWS GetReport/2009-01-01 API call; quota=15 restore=60.00 Returns the contents of a report.

    Required: ReportId

  `get_report_count`(*args, **kw)

    MWS GetReportCount/2009-01-01 API call; quota=10 restore=45.00 Returns a count of the reports, created in the previous 90 days,

    > with a status of _DONE_ and that are available for download.

    Lists: ReportTypeList.Type Booleans: Acknowledged

  `get_report_list`(*args, **kw)

    MWS GetReportList/2009-01-01 API call; quota=10 restore=60.00 Returns a list of reports that were created in the previous

    > 90 days that match the query parameters.

    Lists: ReportRequestIdList.Id, ReportTypeList.Type Booleans: Acknowledged

  `get_report_list_by_next_token`(*args, **kw)

    MWS GetReportListByNextToken/2009-01-01 API call; quota=0 restore=0.00 Returns a list of reports using the NextToken, which

    > was supplied by a previous request to either GetReportListByNextToken or GetReportList, where the value of HasNext was true in the previous call.

    Required: NextToken

  `get_report_request_count`(*args, **kw)

    MWS GetReportRequestCount/2009-01-01 API call; quota=10 restore=45.00 Returns a count of report requests that have been submitted

    > to Amazon MWS for processing.

    Lists: ReportTypeList.Type, ReportProcessingStatusList.Status

  `get_report_request_list`(*args, **kw)

    MWS GetReportRequestList/2009-01-01 API call; quota=10 restore=45.00 Returns a list of report requests that you can use to get the

    > ReportRequestId for a report.

    Lists: ReportRequestIdList.Id, ReportTypeList.Type, ReportProcessingStatusList.Status

  `get_report_request_list_by_next_token`(*args, **kw)

    MWS GetReportRequestListByNextToken/2009-01-01 API call; quota=0 restore=0.00 Returns a list of report requests using the NextToken,

    > which was supplied by a previous request to either GetReportRequestListByNextToken or GetReportRequestList, where the value of HasNext was true in that previous request.

    Required: NextToken

  `get_report_schedule_count`(*args, **kw)

    MWS GetReportScheduleCount/2009-01-01 API call; quota=10 restore=45.00 Returns a count of order report requests that are scheduled

    > to be submitted to Amazon MWS.

    Lists: ReportTypeList.Type

  `get_report_schedule_list`(*args, **kw)

    MWS GetReportScheduleList/2009-01-01 API call; quota=10 restore=45.00 Returns a list of order report requests that are scheduled

    > to be submitted to Amazon MWS for processing.

    Lists: ReportTypeList.Type

  `get_report_schedule_list_by_next_token`(*args, **kw)

    MWS GetReportScheduleListByNextToken/2009-01-01 API call; quota=0 restore=0.00 Returns a list of report requests using the NextToken,

    > which was supplied by a previous request to either GetReportScheduleListByNextToken or GetReportScheduleList, where the value of HasNext was true in that previous request.

    Required: NextToken

  `get_service_status`(**kw)

    Instruct the user on how to get service status.

  `iter_call`(call, *args, **kw)

    Pass a call name as the first argument and a generator is returned for the initial response and any continuation call responses made using the NextToken.

  `iter_response`(response)

    Pass a call’s response as the initial argument and a generator is returned for the initial response and any continuation call responses made using the NextToken.

  `list_all_fulfillment_orders`(*args, **kw)

    MWS ListAllFulfillmentOrders/2010-10-01 API call; quota=30 restore=0.50 Returns a list of fulfillment orders fulfilled after (or at) a specified date or by fulfillment method.

  `list_all_fulfillment_orders_by_next_token`(*args, **kw)

    MWS ListAllFulfillmentOrdersByNextToken/2010-10-01 API call; quota=30 restore=0.50 Returns the next page of inbound shipment items using the

    > NextToken parameter.

    Required: NextToken

  `list_inbound_shipment_items`(*args, **kw)

    MWS ListInboundShipmentItems/2010-10-01 API call; quota=30 restore=0.50 Returns a list of items in a specified inbound shipment, or a

    > list of items that were updated within a specified time frame.

    Required: ShipmentId OR LastUpdatedAfter+LastUpdatedBefore

  `list_inbound_shipment_items_by_next_token`(*args, **kw)

    MWS ListInboundShipmentItemsByNextToken/2010-10-01 API call; quota=30 restore=0.50 Returns the next page of inbound shipment items using the

    > NextToken parameter.

    Required: NextToken

  `list_inbound_shipments`(*args, **kw)

    MWS ListInboundShipments/2010-10-01 API call; quota=30 restore=0.50 Returns a list of inbound shipments based on criteria that

    > you specify.

    Lists: ShipmentIdList.Id, ShipmentStatusList.Status Some Required: ShipmentIdList, ShipmentStatusList

  `list_inbound_shipments_by_next_token`(*args, **kw)

    MWS ListInboundShipmentsByNextToken/2010-10-01 API call; quota=30 restore=0.50 Returns the next page of inbound shipments using the NextToken

    > parameter.

    Required: NextToken

  `list_inventory_supply`(*args, **kw)

    MWS ListInventorySupply/2010-10-01 API call; quota=30 restore=0.50 Returns information about the availability of a seller’s

    > inventory.

    Lists: SellerSkus.member Required: SellerSkus OR QueryStartDateTime

  `list_inventory_supply_by_next_token`(*args, **kw)

    MWS ListInventorySupplyByNextToken/2010-10-01 API call; quota=30 restore=0.50 Returns the next page of information about the availability

    > of a seller’s inventory using the NextToken parameter.

    Required: NextToken

  `list_marketplace_participations`(*args, **kw)

    MWS ListMarketplaceParticipations/2011-07-01 API call; quota=15 restore=60.00 Returns a list of marketplaces that the seller submitting the request can sell in, and a list of participations that include seller-specific information in that marketplace.

  `list_marketplace_participations_by_next_token`(*args, **kw)

    MWS ListMarketplaceParticipationsByNextToken/2011-07-01 API call; quota=15 restore=60.00 Returns the next page of marketplaces and participations

    > using the NextToken value that was returned by your previous request to either ListMarketplaceParticipations or ListMarketplaceParticipationsByNextToken.

    Required: NextToken

  `list_matching_products`(*args, **kw)

    MWS ListMatchingProducts/2011-10-01 API call; quota=20 restore=20.00 Returns a list of products and their attributes, ordered

    > by relevancy, based on a search query that you specify.

    Required: MarketplaceId+Query

  `list_order_items`(*args, **kw)

    MWS ListOrderItems/2011-01-01 API call; quota=30 restore=2.00 Returns order item information for an AmazonOrderId that

    > you specify.

    Required: AmazonOrderId

  `list_order_items_by_next_token`(*args, **kw)

    MWS ListOrderItemsByNextToken/2011-01-01 API call; quota=30 restore=2.00 Returns the next page of order items using the NextToken

    > value that was returned by your previous request to either ListOrderItems or ListOrderItemsByNextToken.

    Required: NextToken

  `list_orders`(*args, **kw)

    MWS ListOrders/2011-01-01 API call; quota=6 restore=60.00 Returns a list of orders created or updated during a time

    > frame that you specify.

    Lists: MarketplaceId.Id, OrderStatus.Status, FulfillmentChannel.Channel, PaymentMethod. Objects: OrderTotal, ShippingAddress, PaymentExecutionDetail Required: MarketplaceId Either: CreatedAfter OR LastUpdatedBefore LastUpdatedBefore requires: LastUpdatedAfter Either: LastUpdatedAfter OR BuyerEmail OR SellerOrderId CreatedBefore requires: CreatedAfter Either: CreatedAfter OR LastUpdatedAfter Required: CreatedAfter OR LastUpdatedAfter

  `list_orders_by_next_token`(*args, **kw)

    MWS ListOrdersByNextToken/2011-01-01 API call; quota=6 restore=60.00 Returns the next page of orders using the NextToken value

    > that was returned by your previous request to either ListOrders or ListOrdersByNextToken.

    Required: NextToken

  `manage_report_schedule`(*args, **kw)

    MWS ManageReportSchedule/2009-01-01 API call; quota=10 restore=45.00 Creates, updates, or deletes a report request schedule for

    > a specified report type.

    Required: ReportType+Schedule

  `method_for`(name)

    Return the MWS API method referred to in the argument. The named method can be in CamelCase or underlined_lower_case. This is the complement to MWSConnection.any_call.action

  `post_request`(path, params, cls, body='', headers={}, isXML=True)

    Make a POST request, optionally with a content body, and return the response, optionally as raw text. Modelled off of the inherited get_object/make_request flow.

  `request_report`(*args, **kw)

    MWS RequestReport/2009-01-01 API call; quota=15 restore=60.00 Creates a report request and submits the request to Amazon MWS.

    Required: ReportType Booleans: ReportOptions=ShowSalesChannel Lists: MarketplaceIdList.Id

  `submit_feed`(*args, **kw)

    MWS SubmitFeed/2009-01-01 API call; quota=15 restore=120.00 Uploads a feed for processing by Amazon MWS.

    Required: FeedType Lists: MarketplaceIdList.Id Required HTTP Body: FeedContent Booleans: PurgeAndReplace

  `update_inbound_shipment`(*args, **kw)

    MWS UpdateInboundShipment/2010-10-01 API call; quota=30 restore=0.50 Updates an existing inbound shipment. Amazon documentation

    > is ambiguous as to whether the InboundShipmentHeader and InboundShipmentItems arguments are required.

    Objects: InboundShipmentHeader, InboundShipmentItems Required: ShipmentId

  `update_report_acknowledgements`(*args, **kw)

    MWS UpdateReportAcknowledgements/2009-01-01 API call; quota=10 restore=45.00 Updates the acknowledged status of one or more reports.

    Lists: ReportIdList.Id Required: ReportIdList Booleans: Acknowledged

## boto.mws.exception

exception `boto.mws.exception.` `InvalidAddress`(status, reason, body=None, *args)

  Invalid address.

exception `boto.mws.exception.` `InvalidParameter`(status, reason, body=None, *args)

  One or more parameters in the request is invalid.

exception `boto.mws.exception.` `InvalidParameterValue`(status, reason, body=None, *args)

  One or more parameter values in the request is invalid.

exception `boto.mws.exception.` `ResponseError`(status, reason, body=None, *args)

  Undefined response error.

  `retry` = False

exception `boto.mws.exception.` `ResponseErrorFactory`(status, reason, body=None, *args)

exception `boto.mws.exception.` `RetriableResponseError`(status, reason, body=None, *args)
  `retry` = True

## boto.mws.response

class `boto.mws.response.` `AttributeSet`(connection=None, name=None, parent=None, attrs=None)
  `ItemDimensions` = <Element_?/?_0x7f84f56784f0>
  `ListPrice` = <Element_?/?_0x7f84f56784f0>
  `PackageDimensions` = <Element_?/?_0x7f84f56784f0>
  `SmallImage` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `CancelFeedSubmissionsResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `CancelReportRequestsResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `CompetitivePrice`(connection=None, name=None, parent=None, attrs=None)
  `Price` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `CompetitivePriceList`(connection=None, name=None, parent=None, attrs=None)
  `CompetitivePrice` = <ElementList_?/?_0x7f84f5676180>

class `boto.mws.response.` `CompetitivePricing`(connection=None, name=None, parent=None, attrs=None)
  `CompetitivePrices` = <Element_?/?_0x7f84f56784f0>
  `NumberOfOfferListings` = <SimpleList_?/?_0x7f84f5674b60>
  `TradeInValue` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `ComplexAmount`(connection=None, name=None, parent=None, attrs=None)
  `endElement`(name, *args, **kw)
  `startElement`(name, *args, **kw)

class `boto.mws.response.` `ComplexDimensions`(connection=None, name=None, parent=None, attrs=None)
  `endElement`(name, *args, **kw)
  `startElement`(name, *args, **kw)

class `boto.mws.response.` `ComplexMoney`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `ComplexType`

class `boto.mws.response.` `ComplexWeight`(connection=None, name=None, parent=None, attrs=None)
  `endElement`(name, *args, **kw)
  `startElement`(name, *args, **kw)

class `boto.mws.response.` `CreateInboundShipmentPlanResult`(connection=None, name=None, parent=None, attrs=None)
  `InboundShipmentPlans` = <MemberList_?/?_0x7f84f569fa50>

class `boto.mws.response.` `DeclarativeType`(_hint=None, **kw)
  `end`(*args, **kw)
  `setup`(parent, name, *args, **kw)
  `start`(*args, **kw)
  `teardown`(*args, **kw)

class `boto.mws.response.` `Dimension`

class `boto.mws.response.` `Element`(_hint=None, **kw)
  `end`(*args, **kw)
  `start`(*args, **kw)

class `boto.mws.response.` `ElementList`(*args, **kw)
  `end`(*args, **kw)
  `start`(*args, **kw)

class `boto.mws.response.` `FeedSubmissionInfo`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `FulfillmentOrder`(connection=None, name=None, parent=None, attrs=None)
  `DestinationAddress` = <Element_?/?_0x7f84f56784f0>
  `NotificationEmailList` = <MemberList_?/?_0x7f84f569fa50>

class `boto.mws.response.` `FulfillmentPreview`(connection=None, name=None, parent=None, attrs=None)
  `EstimatedFees` = <MemberList_?/?_0x7f84f569fa50>
  `EstimatedShippingWeight` = <Element_?/?_0x7f84f56784f0>
  `FulfillmentPreviewShipments` = <MemberList_?/?_0x7f84f569fa50>
  `UnfulfillablePreviewItems` = <MemberList_?/?_0x7f84f569fa50>

class `boto.mws.response.` `FulfillmentPreviewItem`(connection=None, name=None, parent=None, attrs=None)
  `EstimatedShippingWeight` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `GetCompetitivePricingForASINResponse`(*args, **kw)

class `boto.mws.response.` `GetCompetitivePricingForSKUResponse`(*args, **kw)

class `boto.mws.response.` `GetFeedSubmissionCountResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetFeedSubmissionListByNextTokenResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetFeedSubmissionListResult`(connection=None, name=None, parent=None, attrs=None)
  `FeedSubmissionInfo` = <ElementList_?/?_0x7f84f5676180>

class `boto.mws.response.` `GetFulfillmentOrderResult`(connection=None, name=None, parent=None, attrs=None)
  `FulfillmentOrder` = <Element_?/?_0x7f84f56784f0>
  `FulfillmentOrderItem` = <MemberList_?/?_0x7f84f569fa50>
  `FulfillmentShipment` = <MemberList_?/?_0x7f84f569fa50>

class `boto.mws.response.` `GetFulfillmentPreviewResult`(connection=None, name=None, parent=None, attrs=None)
  `FulfillmentPreviews` = <MemberList_?/?_0x7f84f569fa50>

class `boto.mws.response.` `GetLowestOfferListingsForASINResponse`(*args, **kw)

class `boto.mws.response.` `GetLowestOfferListingsForSKUResponse`(*args, **kw)

class `boto.mws.response.` `GetMatchingProductForIdResponse`(*args, **kw)

class `boto.mws.response.` `GetMatchingProductForIdResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetMatchingProductResponse`(*args, **kw)

class `boto.mws.response.` `GetOrderResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetPackageTrackingDetailsResult`(connection=None, name=None, parent=None, attrs=None)
  `ShipToAddress` = <Element_?/?_0x7f84f56784f0>
  `TrackingEvents` = <MemberList_?/?_0x7f84f569fa50>

class `boto.mws.response.` `GetProductCategoriesForASINResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetProductCategoriesForSKUResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetProductCategoriesResult`(connection=None, name=None, parent=None, attrs=None)
  `Self` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `GetReportListByNextTokenResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetReportListResult`(connection=None, name=None, parent=None, attrs=None)
  `ReportInfo` = <ElementList_?/?_0x7f84f5676180>

class `boto.mws.response.` `GetReportRequestListByNextTokenResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetReportRequestListResult`(connection=None, name=None, parent=None, attrs=None)
  `ReportRequestInfo` = <ElementList_?/?_0x7f84f5676180>

class `boto.mws.response.` `GetReportScheduleListByNextTokenResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetReportScheduleListResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `GetServiceStatusResult`(connection=None, name=None, parent=None, attrs=None)
  `Messages` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `Image`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `ItemAttributes`(*args, **kw)
  `Languages` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `ListAllFulfillmentOrdersByNextTokenResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `ListAllFulfillmentOrdersResult`(connection=None, name=None, parent=None, attrs=None)
  `FulfillmentOrders` = <MemberList_?/?_0x7f84f569fa50>

class `boto.mws.response.` `ListInboundShipmentItemsByNextTokenResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `ListInboundShipmentItemsResult`(connection=None, name=None, parent=None, attrs=None)
  `ItemData` = <MemberList_?/?_0x7f84f569fa50>

class `boto.mws.response.` `ListInboundShipmentsByNextTokenResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `ListInboundShipmentsResult`(connection=None, name=None, parent=None, attrs=None)
  `ShipmentData` = <MemberList_?/?_0x7f84f569fa50>

class `boto.mws.response.` `ListInventorySupplyByNextTokenResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `ListInventorySupplyResult`(connection=None, name=None, parent=None, attrs=None)
  `InventorySupplyList` = <MemberList_?/?_0x7f84f569fa50>

class `boto.mws.response.` `ListMarketplaceParticipationsByNextTokenResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `ListMarketplaceParticipationsResult`(connection=None, name=None, parent=None, attrs=None)
  `ListMarketplaces` = <Element_?/?_0x7f84f56784f0>
  `ListParticipations` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `ListMatchingProductsResult`(connection=None, name=None, parent=None, attrs=None)
  `Products` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `ListOrderItemsResult`(connection=None, name=None, parent=None, attrs=None)
  `OrderItems` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `ListOrdersByNextTokenResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `ListOrdersResult`(connection=None, name=None, parent=None, attrs=None)
  `Orders` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `LowestOfferListing`(connection=None, name=None, parent=None, attrs=None)
  `Price` = <Element_?/?_0x7f84f56784f0>
  `Qualifiers` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `ManageReportScheduleResult`(connection=None, name=None, parent=None, attrs=None)
  `ReportSchedule` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `MemberList`(_member=None, _hint=None, *args, **kw)
  `teardown`(*args, **kw)

class `boto.mws.response.` `Order`(connection=None, name=None, parent=None, attrs=None)
  `OrderTotal` = <Element_?/?_0x7f84f56784f0>
  `PaymentExecutionDetail` = <Element_?/?_0x7f84f56784f0>
  `ShippingAddress` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `OrderItem`(connection=None, name=None, parent=None, attrs=None)
  `CODFee` = <Element_?/?_0x7f84f56784f0>
  `CODFeeDiscount` = <Element_?/?_0x7f84f56784f0>
  `GiftWrapPrice` = <Element_?/?_0x7f84f56784f0>
  `GiftWrapTax` = <Element_?/?_0x7f84f56784f0>
  `ItemPrice` = <Element_?/?_0x7f84f56784f0>
  `ItemTax` = <Element_?/?_0x7f84f56784f0>
  `PromotionDiscount` = <Element_?/?_0x7f84f56784f0>
  `PromotionIds` = <SimpleList_?/?_0x7f84f5674b60>
  `ShippingDiscount` = <Element_?/?_0x7f84f56784f0>
  `ShippingPrice` = <Element_?/?_0x7f84f56784f0>
  `ShippingTax` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `Price`(connection=None, name=None, parent=None, attrs=None)
  `LandedPrice` = <Element_?/?_0x7f84f56784f0>
  `ListingPrice` = <Element_?/?_0x7f84f56784f0>
  `Shipping` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `Product`(connection=None, name=None, parent=None, attrs=None)
  `AttributeSets` = <Element_?/?_0x7f84f56784f0>
  `CompetitivePricing` = <ElementList_?/?_0x7f84f5676180>
  `Identifiers` = <Element_?/?_0x7f84f56784f0>
  `LowestOfferListings` = <Element_?/?_0x7f84f56784f0>
  `Relationships` = <Element_?/?_0x7f84f56784f0>
  `SalesRankings` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `ProductCategory`(*args, **kw)

class `boto.mws.response.` `ProductsBulkOperationResponse`(*args, **kw)

class `boto.mws.response.` `ProductsBulkOperationResult`(connection=None, name=None, parent=None, attrs=None)
  `Error` = <Element_?/?_0x7f84f56784f0>
  `Product` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `ReportRequestInfo`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `RequestReportResult`(connection=None, name=None, parent=None, attrs=None)
  `ReportRequestInfo` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `Response`(connection=None, name=None, parent=None, attrs=None)
  `ResponseMetadata` = <Element_?/?_0x7f84f56784f0>
  `startElement`(name, *args, **kw)

class `boto.mws.response.` `ResponseElement`(connection=None, name=None, parent=None, attrs=None)
  `connection`
  `endElement`(name, *args, **kw)
  `startElement`(name, *args, **kw)

`boto.mws.response.` `ResponseFactory`(action, force=None)

class `boto.mws.response.` `ResponseResultList`(*args, **kw)

class `boto.mws.response.` `SalesRank`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `SimpleList`(*args, **kw)
  `end`(name, value, *args, **kw)
  `start`(*args, **kw)

class `boto.mws.response.` `SubmitFeedResult`(connection=None, name=None, parent=None, attrs=None)
  `FeedSubmissionInfo` = <Element_?/?_0x7f84f56784f0>

class `boto.mws.response.` `UpdateReportAcknowledgementsResult`(connection=None, name=None, parent=None, attrs=None)

class `boto.mws.response.` `VariationRelationship`(connection=None, name=None, parent=None, attrs=None)
  `GemType` = <SimpleList_?/?_0x7f84f5674b60>
  `Identifiers` = <Element_?/?_0x7f84f56784f0>
  `MaterialType` = <SimpleList_?/?_0x7f84f5674b60>
  `OperatingSystem` = <SimpleList_?/?_0x7f84f5674b60>

`boto.mws.response.` `strip_namespace`(func)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.16.0 »